@@ -1,19 +1,20 @@
 from django.conf import settings
 from django.db.models import QuerySet, Q
 
+from djangoldp.utils import is_authenticated_user
 from djangoldp.permissions import LDPPermissions, LDPObjectLevelPermissions
 from djangoldp_circle.filters import CircleFilterBackend, CircleMemberFilterBackend
 from djangoldp_circle.xmpp import get_client_ip, XMPP_SERVERS
 
 
-class CirclePermissions(LDPObjectLevelPermissions):
+class CirclePermissions(LDPPermissions):
     filter_backends = [CircleFilterBackend]
 
     def get_object_permissions(self, request, view, obj):
         perms = super().get_object_permissions(request, view, obj)
 
         user = request.user
-        if not user.is_anonymous:
+        if is_authenticated_user(user):
             # permissions gained by being a circle-member, and admin
             if obj.members.filter(user=user).exists():
                 perms = perms.union({'view', 'add'})
@@ -21,9 +22,12 @@ class CirclePermissions(LDPObjectLevelPermissions):
                 if obj.members.filter(user=user).get().is_admin:
                     perms = perms.union({'change', 'delete'})
 
-            # permissions gained by the circle being public
-            if obj.status == 'Public':
-                perms = perms.union({'view', 'add'})
+        # permissions gained by the circle being public
+        if obj.status == 'Public':
+            perms = perms.union({'view'})
+
+            if is_authenticated_user(user):
+                perms = perms.union({'add'})
 
         return perms
 
@@ -41,10 +45,10 @@ class CirclePermissions(LDPObjectLevelPermissions):
         return perms
     
     def has_permission(self, request, view):
-        if get_client_ip(request) in XMPP_SERVERS:
-            return True
+        '''if get_client_ip(request) in XMPP_SERVERS:
+            return True'''
 
-        return super().has_permission(request, view)
+        return True
     
     def has_object_permission(self, request, view, obj):
         if get_client_ip(request) in XMPP_SERVERS:
@@ -61,7 +65,7 @@ class CircleMemberPermissions(LDPPermissions):
 
         user = request.user
 
-        if not user.is_anonymous:
+        if is_authenticated_user(user):
             # the operation is on myself
             if obj.user == user:
                 perms.add('view')
