@@ -23,9 +23,8 @@ config = {
         'BASE_URL': 'http://happy-dev.fr',
         'SEND_BACKLINKS': False,
         'JABBER_DEFAULT_HOST': None,
-        'PERMISSIONS_CACHE': False,
         'ANONYMOUS_USER_NAME': None,
-        'SERIALIZER_CACHE': False
+        'SERIALIZER_CACHE': True
     }
 }
 ldpsettings = LDPSettings(config)
