@@ -80,12 +80,12 @@ class PermissionsTestCase(APITestCase):
         self.assertEqual(len(response.data['ldp:contains']), 1)
 
     # GET circle - not logged in
-    def test_get_circle_anonymous_user(self):
+    def test_get_circle_public_anonymous_user(self):
         another_user = get_random_user()
         self.setUpCircle('Public', another_user)
 
         response = self.client.get('/circles/1/')
-        self.assertEqual(response.status_code, 403)
+        self.assertEqual(response.status_code, 200)
 
     # list circles - not include private circles
     def test_list_circles(self):
